@@ -39,7 +39,7 @@ Override method from L<Pegex::Grammar>.
 
 =cut
 
-sub make_tree {   # Generated/Inlined by Pegex::Grammar (0.63001)
+sub make_tree {   # Generated/Inlined by Pegex::Grammar (0.64)
   {
     '+grammar' => 'graphql',
     '+include' => 'pegex-atoms',
@@ -163,7 +163,7 @@ sub make_tree {   # Generated/Inlined by Pegex::Grammar (0.63001)
               '.ref' => 'operationDefinition'
             },
             {
-              '.ref' => 'fragmentDefinition'
+              '.ref' => 'fragment'
             },
             {
               '.ref' => 'typeSystemDefinition'
@@ -173,20 +173,6 @@ sub make_tree {   # Generated/Inlined by Pegex::Grammar (0.63001)
       ]
     },
     'directive' => {
-      '.all' => [
-        {
-          '.rgx' => qr/\G(?:\s|\x{FEFF}|\#[^\r\n]*(?:\r?\n|\r!NL|\z))*\@/u
-        },
-        {
-          '.ref' => 'name'
-        },
-        {
-          '+max' => 1,
-          '.ref' => 'arguments'
-        }
-      ]
-    },
-    'directiveDefinition' => {
       '.all' => [
         {
           '.rgx' => qr/\Gdirective(?:\s|\x{FEFF}|\#[^\r\n]*(?:\r?\n|\r!NL|\z))*\@(?:\s|\x{FEFF}|\#[^\r\n]*(?:\r?\n|\r!NL|\z))*/u
@@ -228,9 +214,23 @@ sub make_tree {   # Generated/Inlined by Pegex::Grammar (0.63001)
         }
       ]
     },
+    'directiveactual' => {
+      '.all' => [
+        {
+          '.rgx' => qr/\G(?:\s|\x{FEFF}|\#[^\r\n]*(?:\r?\n|\r!NL|\z))*\@/u
+        },
+        {
+          '.ref' => 'name'
+        },
+        {
+          '+max' => 1,
+          '.ref' => 'arguments'
+        }
+      ]
+    },
     'directives' => {
       '+min' => 1,
-      '.ref' => 'directive'
+      '.ref' => 'directiveactual'
     },
     'enumTypeDefinition' => {
       '.all' => [
@@ -350,7 +350,7 @@ sub make_tree {   # Generated/Inlined by Pegex::Grammar (0.63001)
           '.rgx' => qr/\G(?:\s|\x{FEFF}|\#[^\r\n]*(?:\r?\n|\r!NL|\z))*:(?:\s|\x{FEFF}|\#[^\r\n]*(?:\r?\n|\r!NL|\z))*/u
         },
         {
-          '.ref' => 'type'
+          '.ref' => 'typedef'
         },
         {
           '.ref' => '_'
@@ -364,7 +364,7 @@ sub make_tree {   # Generated/Inlined by Pegex::Grammar (0.63001)
     'float' => {
       '.rgx' => qr/\G(\-?(?:0|[1-9][0-9]*)(?:(?:\.[0-9]+)(?:[eE][\-\+]?[0-9]+)|(?:\.[0-9]+)|(?:[eE][\-\+]?[0-9]+)))/
     },
-    'fragmentDefinition' => {
+    'fragment' => {
       '.all' => [
         {
           '.rgx' => qr/\Gfragment(?:\s|\x{FEFF}|\#[^\r\n]*(?:\r?\n|\r!NL|\z))*/u
@@ -417,7 +417,7 @@ sub make_tree {   # Generated/Inlined by Pegex::Grammar (0.63001)
         }
       ]
     },
-    'fragmentSpread' => {
+    'fragment_spread' => {
       '.all' => [
         {
           '-skip' => 1,
@@ -472,7 +472,7 @@ sub make_tree {   # Generated/Inlined by Pegex::Grammar (0.63001)
         }
       ]
     },
-    'inlineFragment' => {
+    'inline_fragment' => {
       '.all' => [
         {
           '-skip' => 1,
@@ -497,7 +497,7 @@ sub make_tree {   # Generated/Inlined by Pegex::Grammar (0.63001)
         }
       ]
     },
-    'inputObjectTypeDefinition' => {
+    'input' => {
       '.all' => [
         {
           '.rgx' => qr/\Ginput(?:\s|\x{FEFF}|\#[^\r\n]*(?:\r?\n|\r!NL|\z))*/u
@@ -533,7 +533,7 @@ sub make_tree {   # Generated/Inlined by Pegex::Grammar (0.63001)
           '.rgx' => qr/\G(?:\s|\x{FEFF}|\#[^\r\n]*(?:\r?\n|\r!NL|\z))*:(?:\s|\x{FEFF}|\#[^\r\n]*(?:\r?\n|\r!NL|\z))*/u
         },
         {
-          '.ref' => 'type'
+          '.ref' => 'typedef'
         },
         {
           '.ref' => '_'
@@ -554,7 +554,7 @@ sub make_tree {   # Generated/Inlined by Pegex::Grammar (0.63001)
     'int' => {
       '.rgx' => qr/\G(\-?(?:0|[1-9][0-9]*))/
     },
-    'interfaceTypeDefinition' => {
+    'interface' => {
       '.all' => [
         {
           '.rgx' => qr/\Ginterface(?:\s|\x{FEFF}|\#[^\r\n]*(?:\r?\n|\r!NL|\z))*/u
@@ -587,7 +587,7 @@ sub make_tree {   # Generated/Inlined by Pegex::Grammar (0.63001)
           '.ref' => 'LSQUARE'
         },
         {
-          '.ref' => 'type'
+          '.ref' => 'typedef'
         },
         {
           '.ref' => 'RSQUARE'
@@ -713,40 +713,6 @@ sub make_tree {   # Generated/Inlined by Pegex::Grammar (0.63001)
         }
       ]
     },
-    'objectTypeDefinition' => {
-      '.all' => [
-        {
-          '.rgx' => qr/\Gtype(?:\s|\x{FEFF}|\#[^\r\n]*(?:\r?\n|\r!NL|\z))*/u
-        },
-        {
-          '.ref' => 'name'
-        },
-        {
-          '.ref' => '_'
-        },
-        {
-          '+max' => 1,
-          '.ref' => 'implementsInterfaces'
-        },
-        {
-          '.ref' => '_'
-        },
-        {
-          '+max' => 1,
-          '.ref' => 'directives'
-        },
-        {
-          '.rgx' => qr/\G(?:\s|\x{FEFF}|\#[^\r\n]*(?:\r?\n|\r!NL|\z))*\{(?:\s|\x{FEFF}|\#[^\r\n]*(?:\r?\n|\r!NL|\z))*/u
-        },
-        {
-          '+min' => 0,
-          '.ref' => 'fieldDefinition'
-        },
-        {
-          '.rgx' => qr/\G(?:\s|\x{FEFF}|\#[^\r\n]*(?:\r?\n|\r!NL|\z))*\}(?:\s|\x{FEFF}|\#[^\r\n]*(?:\r?\n|\r!NL|\z))*/u
-        }
-      ]
-    },
     'objectValue' => {
       '.all' => [
         {
@@ -879,7 +845,7 @@ sub make_tree {   # Generated/Inlined by Pegex::Grammar (0.63001)
         }
       ]
     },
-    'scalarTypeDefinition' => {
+    'scalar' => {
       '.all' => [
         {
           '.rgx' => qr/\Gscalar(?:\s|\x{FEFF}|\#[^\r\n]*(?:\r?\n|\r!NL|\z))*/u
@@ -896,7 +862,7 @@ sub make_tree {   # Generated/Inlined by Pegex::Grammar (0.63001)
         }
       ]
     },
-    'schemaDefinition' => {
+    'schema' => {
       '.all' => [
         {
           '.rgx' => qr/\Gschema(?:\s|\x{FEFF}|\#[^\r\n]*(?:\r?\n|\r!NL|\z))*/u
@@ -923,10 +889,10 @@ sub make_tree {   # Generated/Inlined by Pegex::Grammar (0.63001)
           '.ref' => 'field'
         },
         {
-          '.ref' => 'inlineFragment'
+          '.ref' => 'inline_fragment'
         },
         {
-          '.ref' => 'fragmentSpread'
+          '.ref' => 'fragment_spread'
         }
       ]
     },
@@ -984,15 +950,36 @@ sub make_tree {   # Generated/Inlined by Pegex::Grammar (0.63001)
       '.rgx' => qr/\G"((?:\\(?:["\\\/bfnrt]|u[0-9a-fA-F]{4})|[^"\x00-\x1f\\])*)"/
     },
     'type' => {
-      '.any' => [
+      '.all' => [
         {
-          '.ref' => 'nonNullType'
+          '.rgx' => qr/\Gtype(?:\s|\x{FEFF}|\#[^\r\n]*(?:\r?\n|\r!NL|\z))*/u
         },
         {
-          '.ref' => 'namedType'
+          '.ref' => 'name'
         },
         {
-          '.ref' => 'listType'
+          '.ref' => '_'
+        },
+        {
+          '+max' => 1,
+          '.ref' => 'implementsInterfaces'
+        },
+        {
+          '.ref' => '_'
+        },
+        {
+          '+max' => 1,
+          '.ref' => 'directives'
+        },
+        {
+          '.rgx' => qr/\G(?:\s|\x{FEFF}|\#[^\r\n]*(?:\r?\n|\r!NL|\z))*\{(?:\s|\x{FEFF}|\#[^\r\n]*(?:\r?\n|\r!NL|\z))*/u
+        },
+        {
+          '+min' => 0,
+          '.ref' => 'fieldDefinition'
+        },
+        {
+          '.rgx' => qr/\G(?:\s|\x{FEFF}|\#[^\r\n]*(?:\r?\n|\r!NL|\z))*\}(?:\s|\x{FEFF}|\#[^\r\n]*(?:\r?\n|\r!NL|\z))*/u
         }
       ]
     },
@@ -1009,22 +996,22 @@ sub make_tree {   # Generated/Inlined by Pegex::Grammar (0.63001)
     'typeDefinition' => {
       '.any' => [
         {
-          '.ref' => 'scalarTypeDefinition'
+          '.ref' => 'scalar'
         },
         {
-          '.ref' => 'objectTypeDefinition'
+          '.ref' => 'type'
         },
         {
-          '.ref' => 'interfaceTypeDefinition'
+          '.ref' => 'interface'
         },
         {
-          '.ref' => 'unionTypeDefinition'
+          '.ref' => 'union'
         },
         {
           '.ref' => 'enumTypeDefinition'
         },
         {
-          '.ref' => 'inputObjectTypeDefinition'
+          '.ref' => 'input'
         }
       ]
     },
@@ -1034,7 +1021,7 @@ sub make_tree {   # Generated/Inlined by Pegex::Grammar (0.63001)
           '.rgx' => qr/\Gextend(?:\s|\x{FEFF}|\#[^\r\n]*(?:\r?\n|\r!NL|\z))*/u
         },
         {
-          '.ref' => 'objectTypeDefinition'
+          '.ref' => 'type'
         }
       ]
     },
@@ -1046,7 +1033,7 @@ sub make_tree {   # Generated/Inlined by Pegex::Grammar (0.63001)
         {
           '.any' => [
             {
-              '.ref' => 'schemaDefinition'
+              '.ref' => 'schema'
             },
             {
               '.ref' => 'typeDefinition'
@@ -1055,7 +1042,7 @@ sub make_tree {   # Generated/Inlined by Pegex::Grammar (0.63001)
               '.ref' => 'typeExtensionDefinition'
             },
             {
-              '.ref' => 'directiveDefinition'
+              '.ref' => 'directive'
             }
           ]
         },
@@ -1064,26 +1051,20 @@ sub make_tree {   # Generated/Inlined by Pegex::Grammar (0.63001)
         }
       ]
     },
-    'unionMembers' => {
-      '.all' => [
+    'typedef' => {
+      '.any' => [
+        {
+          '.ref' => 'nonNullType'
+        },
         {
           '.ref' => 'namedType'
         },
         {
-          '+min' => 0,
-          '-flat' => 1,
-          '.all' => [
-            {
-              '.rgx' => qr/\G(?:\s|\x{FEFF}|\#[^\r\n]*(?:\r?\n|\r!NL|\z))*\|(?:\s|\x{FEFF}|\#[^\r\n]*(?:\r?\n|\r!NL|\z))*/u
-            },
-            {
-              '.ref' => 'namedType'
-            }
-          ]
+          '.ref' => 'listType'
         }
       ]
     },
-    'unionTypeDefinition' => {
+    'union' => {
       '.all' => [
         {
           '.rgx' => qr/\Gunion(?:\s|\x{FEFF}|\#[^\r\n]*(?:\r?\n|\r!NL|\z))*/u
@@ -1106,6 +1087,25 @@ sub make_tree {   # Generated/Inlined by Pegex::Grammar (0.63001)
         }
       ]
     },
+    'unionMembers' => {
+      '.all' => [
+        {
+          '.ref' => 'namedType'
+        },
+        {
+          '+min' => 0,
+          '-flat' => 1,
+          '.all' => [
+            {
+              '.rgx' => qr/\G(?:\s|\x{FEFF}|\#[^\r\n]*(?:\r?\n|\r!NL|\z))*\|(?:\s|\x{FEFF}|\#[^\r\n]*(?:\r?\n|\r!NL|\z))*/u
+            },
+            {
+              '.ref' => 'namedType'
+            }
+          ]
+        }
+      ]
+    },
     'value' => {
       '.any' => [
         {
@@ -1184,7 +1184,7 @@ sub make_tree {   # Generated/Inlined by Pegex::Grammar (0.63001)
           '.rgx' => qr/\G(?:\s|\x{FEFF}|\#[^\r\n]*(?:\r?\n|\r!NL|\z))*:(?:\s|\x{FEFF}|\#[^\r\n]*(?:\r?\n|\r!NL|\z))*/u
         },
         {
-          '.ref' => 'type'
+          '.ref' => 'typedef'
         },
         {
           '+max' => 1,
