@@ -14,6 +14,24 @@ require GraphQL::Grammar;
 
 my $JSON = JSON::MaybeXS->new->allow_nonref->canonical;
 
+my @KINDHASH = qw(
+  scalar
+  union
+  field
+  inline_fragment
+  fragment_spread
+  fragment
+  directive
+);
+my %KINDHASH21 = map { ($_ => 1) } @KINDHASH;
+
+my @KINDFIELDS = qw(
+  type
+  input
+  interface
+);
+my %KINDFIELDS21 = map { ($_ => 1) } @KINDFIELDS;
+
 =head1 NAME
 
 GraphQL::Parser - GraphQL language parser
@@ -58,6 +76,11 @@ method parse(Str $source, Bool $noLocation = undef) :ReturnType(ArrayRef) {
 
 method gotrule (Any $param = undef) {
   return unless defined $param;
+  if ($KINDHASH21{$self->{parser}{rule}}) {
+    return {kind => $self->{parser}{rule}, node => _merge_hash($param)};
+  } elsif ($KINDFIELDS21{$self->{parser}{rule}}) {
+    return {kind => $self->{parser}{rule}, node => _merge_hash($param, 'fields')};
+  }
   return {$self->{parser}{rule} => $param};
 }
 
@@ -66,33 +89,37 @@ method final (Any $param = undef) {
   return {$self->{parser}{rule} => []};
 }
 
+fun _merge_hash (Any $param = undef, Any $arraykey = undef) {
+  my %def = map %$_, grep ref eq 'HASH', @$param;
+  if ($arraykey) {
+    my @arrays = grep ref eq 'ARRAY', @$param;
+    die "More than one array found\n" if @arrays > 1;
+    die "No arrays found but \$arraykey given\n" if !@arrays;
+    my %fields = map %$_, @{$arrays[0]};
+    $def{$arraykey} = \%fields;
+  }
+  \%def;
+}
+
 method got_arguments (Any $param = undef) {
   return unless defined $param;
-  $param = $param->[0]; # zap first useless layer
-  my %args;
-  for my $arg (@$param) {
-    ($arg) = values %$arg; # zap useless layer
-    my $name = shift @$arg;
-    $args{$name} = shift @$arg;
-  }
+  my %args = map { ($_->[0]{name} => $_->[1]) } @{$param->[0]};
   return {$self->{parser}{rule} => \%args};
 }
 
+method got_argument (Any $param = undef) {
+  return unless defined $param;
+  $param;
+}
+
 method got_objectField (Any $param = undef) {
   return unless defined $param;
-  my $name = shift @$param;
-  my $value = shift @$param;
-  return {$name => $value};
+  return {$param->[0]{name} => $param->[1]};
 }
 
 method got_objectValue (Any $param = undef) {
   return unless defined $param;
-  $param = $param->[0]; # zap first useless layer
-  my %value;
-  while (my $arg = shift @$param) {
-    %value = (%value, %$arg);
-  }
-  return \%value;
+  _merge_hash($param->[0]);
 }
 
 method got_objectField_const (Any $param = undef) {
@@ -105,71 +132,39 @@ method got_objectValue_const (Any $param = undef) {
 
 method got_listValue (Any $param = undef) {
   return unless defined $param;
-  $param = $param->[0]; # zap first useless layer
-  return $param;
+  return $param->[0];
 }
 
 method got_listValue_const (Any $param = undef) {
   unshift @_, $self; goto &got_listValue;
 }
 
-method got_directive (Any $param = undef) {
+method got_directiveactual (Any $param = undef) {
   return unless defined $param;
-  my %value;
-  my $arg = shift @$param;
-  $value{name} = $arg;
-  if ($arg = shift @$param) {
-    %value = (%value, %$arg);
-  }
-  return {$self->{parser}{rule} => \%value};
+  _merge_hash($param);
 }
 
 method got_inputValueDefinition (Any $param = undef) {
   return unless defined $param;
-  my %value;
-  my $arg = shift @$param;
-  $value{name} = $arg;
-  while ($arg = shift @$param) {
-    %value = (%value, %$arg);
-  }
-  return {$self->{parser}{rule} => \%value};
+  my $def = _merge_hash($param);
+  my $name = delete $def->{name};
+  return { $name => $def };
 }
 
 method got_directiveLocations (Any $param = undef) {
   return unless defined $param;
-  return {locations => $param};
-}
-
-method got_name (Any $param = undef) {
-  return unless defined $param;
-  return $param;
+  return {locations => [ map $_->{name}, @$param ]};
 }
 
 method got_namedType (Any $param = undef) {
   return unless defined $param;
-  return $param;
-}
-
-method got_scalarTypeDefinition (Any $param = undef) {
-  return unless defined $param;
-  my %def;
-  my $arg = shift @$param;
-  $def{name} = $arg;
-  while ($arg = shift @$param) {
-    %def = (%def, %$arg);
-  }
-  return {kind => 'scalar', node => \%def};
+  return $param->{name};
 }
 
 method got_enumValueDefinition (Any $param = undef) {
   return unless defined $param;
-  my %value;
-  my $arg = shift @$param;
-  $value{value} = $arg;
-  while ($arg = shift @$param) {
-    %value = (%value, %$arg);
-  }
-  return {$self->{parser}{rule} => \%value};
+  my %def = (value => shift @$param, map %$_, @$param);
+  return \%def;
 }
 
 method got_defaultValue (Any $param = undef) {
@@ -179,35 +174,19 @@ method got_defaultValue (Any $param = undef) {
 
 method got_implementsInterfaces (Any $param = undef) {
   return unless defined $param;
-  $param = $param->[0]; # zap first useless layer
-  return { interfaces => $param };
+  return { interfaces => $param->[0] };
 }
 
 method got_argumentsDefinition (Any $param = undef) {
   return unless defined $param;
-  $param = $param->[0]; # zap first useless layer
-  my %args;
-  map {
-    my $name = delete $_->{name};
-    $args{$name} = $_;
-  } map $_->{inputValueDefinition}, @$param;
-  return { args => \%args };
+  return { args => _merge_hash($param->[0])};
 }
 
-method got_objectTypeDefinition (Any $param = undef) {
+method got_fieldDefinition (Any $param = undef) {
   return unless defined $param;
-  my %def;
-  $def{name} = shift @$param;
-  %def = (%def, %{shift @$param}) while ref($param->[0]) eq 'HASH';
-  my %fields;
-  map {
-    my $name = shift @$_;
-    my %field_def;
-    %field_def = (%field_def, %{shift @$_}) while @$_;
-    $fields{$name} = \%field_def;
-  } map $_->{fieldDefinition}, @{shift @$param};
-  $def{fields} = \%fields;
-  return {kind => 'type', node => \%def};
+  my $def = _merge_hash($param);
+  my $name = delete $def->{name};
+  return { $name => $def };
 }
 
 method got_typeExtensionDefinition (Any $param = undef) {
@@ -217,57 +196,21 @@ method got_typeExtensionDefinition (Any $param = undef) {
   return $node;
 }
 
-method got_inputObjectTypeDefinition (Any $param = undef) {
-  return unless defined $param;
-  my %def;
-  $def{name} = shift @$param;
-  %def = (%def, %{shift @$param}) while ref($param->[0]) eq 'HASH';
-  my %fields;
-  map {
-    my $name = delete $_->{name};
-    $fields{$name} = $_;
-  } map $_->{inputValueDefinition}, @{shift @$param};
-  $def{fields} = \%fields;
-  return {kind => 'input', node => \%def};
-}
-
 method got_enumTypeDefinition (Any $param = undef) {
   return unless defined $param;
-  my %def;
-  $def{name} = shift @$param;
-  %def = (%def, %{shift @$param}) while ref($param->[0]) eq 'HASH';
+  my $def = _merge_hash($param);
   my %values;
   map {
     my $name = ${${delete $_->{value}}};
     $values{$name} = $_;
-  } map $_->{enumValueDefinition}, @{shift @$param};
-  $def{values} = \%values;
-  return {kind => 'enum', node => \%def};
+  } @{(grep ref eq 'ARRAY', @$param)[0]};
+  $def->{values} = \%values;
+  return {kind => 'enum', node => $def};
 }
 
-method got_interfaceTypeDefinition (Any $param = undef) {
+method got_unionMembers (Any $param = undef) {
   return unless defined $param;
-  my %def;
-  $def{name} = shift @$param;
-  %def = (%def, %{shift @$param}) while ref($param->[0]) eq 'HASH';
-  my %fields;
-  map {
-    my $name = shift @$_;
-    my %field_def;
-    %field_def = (%field_def, %{shift @$_}) while @$_;
-    $fields{$name} = \%field_def;
-  } map $_->{fieldDefinition}, @{shift @$param};
-  $def{fields} = \%fields;
-  return {kind => 'interface', node => \%def};
-}
-
-method got_unionTypeDefinition (Any $param = undef) {
-  return unless defined $param;
-  my %def;
-  $def{name} = shift @$param;
-  %def = (%def, %{shift @$param}) while ref($param->[0]) eq 'HASH';
-  $def{types} = delete $def{unionMembers};
-  return {kind => 'union', node => \%def};
+  return { types => $param };
 }
 
 method got_boolean (Any $param = undef) {
@@ -286,18 +229,17 @@ method got_string (Any $param = undef) {
 }
 
 method got_int (Any $param = undef) {
-  $_[0] += 0; # numify. if modify $param gets dropped as is local copy
-  unshift @_, $self; goto &got_string;
+  $param+0;
 }
 
 method got_float (Any $param = undef) {
-  $_[0] += 0; # numify. if modify $param gets dropped as is local copy
-  unshift @_, $self; goto &got_string;
+  $param+0;
 }
 
 method got_enumValue (Any $param = undef) {
   return unless defined $param;
-  return \\$param;
+  my $varname = $param->{name};
+  return \\$varname;
 }
 
 # not returning empty list if undef
@@ -311,27 +253,37 @@ method got_value (Any $param = undef) {
 
 method got_variableDefinitions (Any $param = undef) {
   return unless defined $param;
-  $param = $param->[0]; # zap first useless layer
   my %def;
   map {
     my $name = ${ shift @$_ };
     $def{$name} = { map %$_, @$_ }; # merge
-  } map $_->{variableDefinition}, @$param;
+  } @{$param->[0]};
   return {variables => \%def};
 }
 
+method got_variableDefinition (Any $param = undef) {
+  return unless defined $param;
+  return $param;
+}
+
 method got_selection (Any $param = undef) {
   unshift @_, $self; goto &got_value_const;
 }
 
+method got_typedef (Any $param = undef) {
+  return unless defined $param;
+  $param = $param->{name} if ref($param) eq 'HASH';
+  return {type => $param};
+}
+
 method got_alias (Any $param = undef) {
   return unless defined $param;
-  return {$self->{parser}{rule} => @$param};
+  return {$self->{parser}{rule} => $param->[0]{name}};
 }
 
 method got_typeCondition (Any $param = undef) {
   return unless defined $param;
-  return {on => @$param};
+  return {on => $param->[0]};
 }
 
 method got_fragmentName (Any $param = undef) {
@@ -339,68 +291,20 @@ method got_fragmentName (Any $param = undef) {
   return $param;
 }
 
-method got_field (Any $param = undef) {
-  return unless defined $param;
-  my %def;
-  %def = (%def, %{shift @$param}) if ref($param->[0]) eq 'HASH'; # alias
-  $def{name} = shift @$param;
-  %def = (%def, %{shift @$param}) while ref($param->[0]) eq 'HASH';
-  return {kind => 'field', node => \%def};
-}
-
-method got_inlineFragment (Any $param = undef) {
-  return unless defined $param;
-  my %def;
-  %def = (%def, %{shift @$param}) while ref($param->[0]) eq 'HASH';
-  return {kind => 'inline_fragment', node => \%def};
-}
-
-method got_fragmentSpread (Any $param = undef) {
-  return unless defined $param;
-  my %def;
-  $def{name} = shift @$param;
-  %def = (%def, %{shift @$param}) while @$param;
-  return {kind => 'fragment_spread', node => \%def};
-}
-
 method got_selectionSet (Any $param = undef) {
   return unless defined $param;
-  $param = $param->[0]; # zap first useless layer
-  return {selections => $param};
-}
-
-method got_fragmentDefinition (Any $param = undef) {
-  return unless defined $param;
-  my %def;
-  $def{name} = shift @$param;
-  %def = (%def, %{shift @$param}) while @$param;
-  return {kind => 'fragment', node => \%def};
+  return {selections => $param->[0]};
 }
 
 method got_operationDefinition (Any $param = undef) {
   return unless defined $param;
   $param = [ $param ] unless ref $param eq 'ARRAY'; # bare selectionSet
-  my %def;
-  map {
-    $_ = { name => $_ } if !ref $_;
-    %def = (%def, %$_);
-  } @$param;
-  return {kind => 'operation', node => \%def};
-}
-
-method got_directiveDefinition (Any $param = undef) {
-  return unless defined $param;
-  my %def;
-  map {
-    $_ = { name => $_ } if !ref $_;
-    %def = (%def, %$_);
-  } @$param;
-  return {kind => 'directive', node => \%def};
+  return {kind => 'operation', node => _merge_hash($param)};
 }
 
 method got_directives (Any $param = undef) {
   return unless defined $param;
-  return {$self->{parser}{rule} => [ map $_->{directive}, @$param ]};
+  return {$self->{parser}{rule} => $param};
 }
 
 method got_graphql (Any $param = undef) {
@@ -418,14 +322,9 @@ method got_operationTypeDefinition (Any $param = undef) {
   return { map { ref($_) ? values %$_ : $_ } @$param };
 }
 
-method got_schemaDefinition (Any $param = undef) {
+method got_schema (Any $param = undef) {
   return unless defined $param;
-  $param = $param->[0]; # zap first useless layer
-  my %def;
-  map {
-    %def = (%def, %$_);
-  } @$param;
-  return {kind => 'schema', node => \%def};
+  return {kind => $self->{parser}{rule}, node => _merge_hash($param->[0])};
 }
 
 method got_typeSystemDefinition (Any $param = undef) {
@@ -440,7 +339,7 @@ method got_typeDefinition (Any $param = undef) {
 
 method got_variable (Any $param = undef) {
   return unless defined $param;
-  my $varname = shift @$param;
+  my $varname = $param->[0]{name};
   return \$varname;
 }
 
